@@ -51,7 +51,7 @@ API_DOOR = API_BASE_URL + "corp/site/door/{}"
 API_GATEWAY = API_BASE_URL + "corp/site/gateway/{}"
 API_BOOKING = API_BASE_URL + "corp/site/booking/{}"
 API_USER = API_BASE_URL + "corp/user/{}"
-API_CORP_DOOR_COMMANDS = API_BASE_URL + "corp/site/send/door/{}"
+API_CORP_DOOR_COMMANDS = API_BASE_URL + "corp/site/door/send/{}"
 API_ROLE = API_BASE_URL + "corp/role/{}"
 
 
