@@ -27,7 +27,7 @@ class DoorAPI(LoopkeyAPI):
         Get door.
         :return: Response object from requests library with Door json.
         """
-        return self._call_action(requests.get, "get")
+        return self._call_action(requests.get, "get", params={"id": self._id})
 
     def list_online_doors(self) -> requests.Response:
         """
